==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/deviceregistry/kotlin/inputs/UsernamePasswordCredentialsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.deviceregistry.kotlin.inputs

import com.pulumi.azurenative.deviceregistry.inputs.UsernamePasswordCredentialsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The credentials for authentication mode UsernamePassword.
 * @property passwordReference A reference to secret containing the password.
 * @property usernameReference A reference to secret containing the username.
 */
public data class UsernamePasswordCredentialsArgs(
    public val passwordReference: Output<String>,
    public val usernameReference: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.deviceregistry.inputs.UsernamePasswordCredentialsArgs> {
    override fun toJava():
        com.pulumi.azurenative.deviceregistry.inputs.UsernamePasswordCredentialsArgs =
        com.pulumi.azurenative.deviceregistry.inputs.UsernamePasswordCredentialsArgs.builder()
            .passwordReference(passwordReference.applyValue({ args0 -> args0 }))
            .usernameReference(usernameReference.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UsernamePasswordCredentialsArgs].
 */
@PulumiTagMarker
public class UsernamePasswordCredentialsArgsBuilder internal constructor() {
    private var passwordReference: Output<String>? = null

    private var usernameReference: Output<String>? = null

    /**
     * @param value A reference to secret containing the password.
     */
    @JvmName("qijekycbsydheykj")
    public suspend fun passwordReference(`value`: Output<String>) {
        this.passwordReference = value
    }

    /**
     * @param value A reference to secret containing the username.
     */
    @JvmName("slstavlgijowxdrf")
    public suspend fun usernameReference(`value`: Output<String>) {
        this.usernameReference = value
    }

    /**
     * @param value A reference to secret containing the password.
     */
    @JvmName("wnokwchrdgaxdrsd")
    public suspend fun passwordReference(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.passwordReference = mapped
    }

    /**
     * @param value A reference to secret containing the username.
     */
    @JvmName("dfhfnvteacslsecv")
    public suspend fun usernameReference(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.usernameReference = mapped
    }

    internal fun build(): UsernamePasswordCredentialsArgs = UsernamePasswordCredentialsArgs(
        passwordReference = passwordReference ?: throw PulumiNullFieldException("passwordReference"),
        usernameReference = usernameReference ?: throw PulumiNullFieldException("usernameReference"),
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/deviceregistry/kotlin/inputs/UsernamePasswordCredentialsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.deviceregistry.kotlin.inputs

import com.pulumi.azurenative.deviceregistry.inputs.UsernamePasswordCredentialsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The credentials for authentication mode UsernamePassword.
 * @property passwordReference A reference to secret containing the password.
 * @property usernameReference A reference to secret containing the username.
 */
public data class UsernamePasswordCredentialsArgs(
    public val passwordReference: Output<String>,
    public val usernameReference: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.deviceregistry.inputs.UsernamePasswordCredentialsArgs> {
    override fun toJava(): com.pulumi.azurenative.deviceregistry.inputs.UsernamePasswordCredentialsArgs =
        com.pulumi.azurenative.deviceregistry.inputs.UsernamePasswordCredentialsArgs.builder()
            .passwordReference(passwordReference.applyValue({ args0 -> args0 }))
            .usernameReference(usernameReference.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UsernamePasswordCredentialsArgs].
 */
@PulumiTagMarker
public class UsernamePasswordCredentialsArgsBuilder internal constructor() {
    private var passwordReference: Output<String>? = null

    private var usernameReference: Output<String>? = null

    /**
     * @param value A reference to secret containing the password.
     */
    @JvmName("ipgbykjfqnyyvvwl")
    public suspend fun passwordReference(`value`: Output<String>) {
        this.passwordReference = value
    }

    /**
     * @param value A reference to secret containing the username.
     */
    @JvmName("jugpsbljtalchdpt")
    public suspend fun usernameReference(`value`: Output<String>) {
        this.usernameReference = value
    }

    /**
     * @param value A reference to secret containing the password.
     */
    @JvmName("qkntbogigtgkpsdk")
    public suspend fun passwordReference(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.passwordReference = mapped
    }

    /**
     * @param value A reference to secret containing the username.
     */
    @JvmName("guyegiyqeqwkbvkf")
    public suspend fun usernameReference(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.usernameReference = mapped
    }

    internal fun build(): UsernamePasswordCredentialsArgs = UsernamePasswordCredentialsArgs(
        passwordReference = passwordReference ?: throw PulumiNullFieldException("passwordReference"),
        usernameReference = usernameReference ?: throw PulumiNullFieldException("usernameReference"),
    )
}
